# 003

|                                                | Asko professional washing machine   |
|:-----------------------------------------------|:------------------------------------|
| bindTime                                       | 1634119536189                       |
| createTime                                     | 0                                   |
| deviceFeatureCode                              | 000                                 |
| deviceFeatureName                              | ASKO Pro Washing Machine            |
| deviceId                                       | <redacted>                          |
| deviceNickName                                 | wm Andrej                           |
| deviceTypeCode                                 | 003                                 |
| deviceTypeName                                 |                                     |
| offlineState                                   | 0                                   |
| puid                                           | <redacted>                          |
| role                                           | 1                                   |
| roomId                                         | 106345                              |
| roomName                                       | default_room                        |
| seq                                            | 0                                   |
| statusList.ACTION                              | 0                                   |
| statusList.AddClothes                          | 1                                   |
| statusList.AlarmCleanFilterWarning             | 0                                   |
| statusList.AlarmFillAdContainer1Warning        | 0                                   |
| statusList.AlarmFillAdContainer2Warning        | 0                                   |
| statusList.AlarmFoamDetection                  | 0                                   |
| statusList.AlarmOptionNotAvailable             | 0                                   |
| statusList.AlarmPowerFailAlert                 | 0                                   |
| statusList.AlarmSteriltubRunWarning            | 0                                   |
| statusList.AlarmWashFinished                   | 0                                   |
| statusList.AllergyModeEnable                   | 0                                   |
| statusList.BlockDetailedProgramView            | 1                                   |
| statusList.BookAvailableTime                   | 0                                   |
| statusList.BookReservedTime                    | 0                                   |
| statusList.BookTimeToEndReservation            | 0                                   |
| statusList.Booking                             | 0                                   |
| statusList.Brightness                          | 2                                   |
| statusList.ChildLockActive                     | 0                                   |
| statusList.ChildLockEnabled                    | 0                                   |
| statusList.ColdWash                            | 0                                   |
| statusList.CurrentProgramPhase                 | 0                                   |
| statusList.CurrentWaterTemperature             | 30                                  |
| statusList.DelayStartCountdownTimer            | 0                                   |
| statusList.DemoMode                            | 0                                   |
| statusList.DeviceStatus                        | 0                                   |
| statusList.DoorStatus                          | 0                                   |
| statusList.Drain                               | 1                                   |
| statusList.DrumVleanProgramWarning             | 1                                   |
| statusList.Error0                              | 0                                   |
| statusList.Error1                              | 0                                   |
| statusList.Error10                             | 0                                   |
| statusList.Error11                             | 0                                   |
| statusList.Error12                             | 0                                   |
| statusList.Error12_1                           | 0                                   |
| statusList.Error12_10                          | 0                                   |
| statusList.Error12_12                          | 0                                   |
| statusList.Error12_2                           | 0                                   |
| statusList.Error12_3                           | 0                                   |
| statusList.Error12_4                           | 0                                   |
| statusList.Error12_5                           | 0                                   |
| statusList.Error12_6                           | 0                                   |
| statusList.Error12_7                           | 0                                   |
| statusList.Error12_8                           | 0                                   |
| statusList.Error12_9                           | 0                                   |
| statusList.Error13                             | 0                                   |
| statusList.Error13_1                           | 0                                   |
| statusList.Error13_2                           | 0                                   |
| statusList.Error13_3                           | 0                                   |
| statusList.Error15                             | 0                                   |
| statusList.Error2                              | 0                                   |
| statusList.Error22                             | 0                                   |
| statusList.Error23                             | 0                                   |
| statusList.Error24                             | 0                                   |
| statusList.Error25                             | 0                                   |
| statusList.Error26                             | 0                                   |
| statusList.Error27                             | 0                                   |
| statusList.Error28                             | 0                                   |
| statusList.Error29                             | 0                                   |
| statusList.Error3                              | 0                                   |
| statusList.Error30                             | 0                                   |
| statusList.Error31                             | 0                                   |
| statusList.Error32                             | 0                                   |
| statusList.Error33                             | 0                                   |
| statusList.Error34                             | 0                                   |
| statusList.Error35                             | 0                                   |
| statusList.Error36                             | 0                                   |
| statusList.Error37                             | 0                                   |
| statusList.Error38                             | 0                                   |
| statusList.Error39                             | 0                                   |
| statusList.Error4                              | 0                                   |
| statusList.Error40                             | 0                                   |
| statusList.Error41                             | 0                                   |
| statusList.Error42                             | 0                                   |
| statusList.Error43                             | 0                                   |
| statusList.Error44                             | 0                                   |
| statusList.Error45                             | 0                                   |
| statusList.Error46                             | 0                                   |
| statusList.Error47                             | 0                                   |
| statusList.Error5                              | 0                                   |
| statusList.Error6                              | 0                                   |
| statusList.Error7                              | 0                                   |
| statusList.Error7_1                            | 0                                   |
| statusList.Error8                              | 0                                   |
| statusList.Error9                              | 0                                   |
| statusList.ExtraRinse                          | 0                                   |
| statusList.FailureReadOut1                     | 3                                   |
| statusList.FailureReadOut10                    | 3                                   |
| statusList.FailureReadOut10LastCycle           | 2                                   |
| statusList.FailureReadOut10NumberOfRepetiotion | 0                                   |
| statusList.FailureReadOut1LastCycle            | 18                                  |
| statusList.FailureReadOut1NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut2                     | 3                                   |
| statusList.FailureReadOut2LastCycle            | 18                                  |
| statusList.FailureReadOut2NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut3                     | 3                                   |
| statusList.FailureReadOut3LastCycle            | 16                                  |
| statusList.FailureReadOut3NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut4                     | 3                                   |
| statusList.FailureReadOut4LastCycle            | 13                                  |
| statusList.FailureReadOut4NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut5                     | 3                                   |
| statusList.FailureReadOut5LastCycle            | 6                                   |
| statusList.FailureReadOut5NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut6                     | 3                                   |
| statusList.FailureReadOut6LastCycle            | 5                                   |
| statusList.FailureReadOut6NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut7                     | 3                                   |
| statusList.FailureReadOut7LastCycle            | 4                                   |
| statusList.FailureReadOut7NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut8                     | 3                                   |
| statusList.FailureReadOut8LastCycle            | 3                                   |
| statusList.FailureReadOut8NumberOfRepetiotion  | 0                                   |
| statusList.FailureReadOut9                     | 3                                   |
| statusList.FailureReadOut9LastCycle            | 2                                   |
| statusList.FailureReadOut9NumberOfRepetiotion  | 0                                   |
| statusList.HardPairingStatus                   | 0                                   |
| statusList.HeatingSteps                        | 1                                   |
| statusList.IDCode                              | 230                                 |
| statusList.Identified                          | 0                                   |
| statusList.Language                            | 0                                   |
| statusList.Load                                | 3                                   |
| statusList.Logo                                | 1                                   |
| statusList.MaxTimeEvent                        | 0                                   |
| statusList.MotorSpeed1000RPMAvailable          | 1                                   |
| statusList.MotorSpeed100RPMAvailable           | 1                                   |
| statusList.MotorSpeed1100RPMAvailable          | 1                                   |
| statusList.MotorSpeed1200RPMAvailable          | 1                                   |
| statusList.MotorSpeed1300RPMAvailable          | 1                                   |
| statusList.MotorSpeed1400RPMAvailable          | 1                                   |
| statusList.MotorSpeed1500RPMAvailable          | 1                                   |
| statusList.MotorSpeed1600RPMAvailable          | 1                                   |
| statusList.MotorSpeed400RPMAvailable           | 1                                   |
| statusList.MotorSpeed500RPMAvailable           | 1                                   |
| statusList.MotorSpeed600RPMAvailable           | 1                                   |
| statusList.MotorSpeed800RPMAvailable           | 1                                   |
| statusList.MotorSpeed900RPMAvailable           | 1                                   |
| statusList.MotorSpeedNoDrainAvailable          | 1                                   |
| statusList.MotorSpeedNoSpinAvailable           | 1                                   |
| statusList.PPUOnlineCoinSystem                 | 0                                   |
| statusList.PPURECIPSS                          | 1                                   |
| statusList.PPUWashEnabled                      | 0                                   |
| statusList.PPUWashTable1Finished               | 0                                   |
| statusList.PPUWashTable1PID                    | 0                                   |
| statusList.PPUWashTable1Time                   | 0                                   |
| statusList.PPUWashTable2Finished               | 0                                   |
| statusList.PPUWashTable2PID                    | 0                                   |
| statusList.PPUWashTable2Time                   | 0                                   |
| statusList.PPUWashTable3Finished               | 0                                   |
| statusList.PPUWashTable3PID                    | 0                                   |
| statusList.PPUWashTable3Time                   | 0                                   |
| statusList.PPUWashTable4Finished               | 0                                   |
| statusList.PPUWashTable4PID                    | 0                                   |
| statusList.PPUWashTable4Time                   | 0                                   |
| statusList.PPUWashTable5Finished               | 0                                   |
| statusList.PPUWashTable5PID                    | 0                                   |
| statusList.PPUWashTable5Time                   | 0                                   |
| statusList.PaidByCoinBox                       | 1                                   |
| statusList.ParseLibVersion                     | 511108                              |
| statusList.PaymentEnabledTimer                 | 0                                   |
| statusList.PaymentSystem                       | 0                                   |
| statusList.ProgramOptionTimeStartDelayHour     | 0                                   |
| statusList.ProgramRemainingTime                | 0                                   |
| statusList.RemoteControlMode                   | 2                                   |
| statusList.RemoteSetControlEnabled             | 1                                   |
| statusList.RemoteStartDuration                 | 10                                  |
| statusList.RemoteStartEnabled                  | 1                                   |
| statusList.SelectedBasicID                     | 54                                  |
| statusList.SelectedDerivedID                   | 0                                   |
| statusList.SelectedProgram                     | 15                                  |
| statusList.Sensor3D                            | 1                                   |
| statusList.SessionPairingActive                | 3                                   |
| statusList.SessionPairingRequest               | 0                                   |
| statusList.SessionPairingSetting               | 1                                   |
| statusList.SetMaxMotorSpeed                    | 16                                  |
| statusList.ShowMeasuredTemperature             | 0                                   |
| statusList.SoftPairingSetting                  | 1                                   |
| statusList.Sound                               | 0                                   |
| statusList.SpinTime                            | 100                                 |
| statusList.StandbyChoice                       | 0                                   |
| statusList.StartDelayFunction                  | 1                                   |
| statusList.TemperatureUnit                     | 0                                   |
| statusList.TemporaryLanguageSelected           | 0                                   |
| statusList.TemporaryLanguageSettingEnabled     | 1                                   |
| statusList.TimeIconSetting                     | 1                                   |
| statusList.TotalProgramCycles                  | 17                                  |
| statusList.Volume                              | 0                                   |
| statusList.daily_energy_kwh                    | 0                                   |
| statusList.reserved1                           | 0                                   |
| statusList.reserved125                         | 0                                   |
| statusList.reserved2                           | 0                                   |
| statusList.reserved3                           | 0                                   |
| statusList.reserved4                           | 0                                   |
| useTime                                        | 0                                   |
| wifiId                                         | <redacted>                          |

## Generated from

- [`Asko_professional_washing_machine.json`](Asko_professional_washing_machine.json)
